// ../core/dist/index.js
var IFRAME_STYLE = {
  width: "400px",
  height: "600px",
  border: "none",
  borderRadius: "24px",
  minWidth: "320px"
};
var IFRAME_PERMISSIONS = "camera *; microphone *; clipboard-read; clipboard-write; payment";
var PRODUCTION_WIDGET_URL = "https://app.swipelux.com";
var WidgetIframeManager = class {
  constructor(iframe, settings, callbacks) {
    this.iframe = iframe;
    this.settings = settings;
    this.callbacks = callbacks;
    this.messageHandler = this.handleMessageEvent.bind(this);
  }
  initialize() {
    window.addEventListener("message", this.messageHandler);
    this.setupIframe();
  }
  destroy() {
    window.removeEventListener("message", this.messageHandler);
  }
  get widgetUrl() {
    var _a;
    return (_a = this.settings.widgetUrl) != null ? _a : PRODUCTION_WIDGET_URL;
  }
  get iframeSrc() {
    const iframeSrc = new URL(this.widgetUrl);
    iframeSrc.searchParams.set("api-key", this.settings.apiKey);
    return iframeSrc.toString();
  }
  setupIframe() {
    this.iframe.src = this.iframeSrc;
    this.iframe.onload = () => this.handleIframeLoad();
  }
  handleIframeLoad() {
    var _a;
    const message = {
      type: "START_APPLICATION",
      payload: {
        ...this.settings,
        analyticsInfo: {
          screenWidth: window.innerWidth,
          screenHeight: window.innerHeight,
          merchantUrl: window.location.host,
          initTimestamp: Date.now()
        }
      }
    };
    (_a = this.iframe.contentWindow) == null ? void 0 : _a.postMessage(message, this.widgetUrl);
  }
  handleMessageEvent(event) {
    var _a, _b, _c, _d;
    if (!this.widgetUrl.includes(event.origin)) {
      return;
    }
    switch (event.data.type) {
      case "CREATE_REDIRECT":
        window.open(event.data.payload.url, "_self");
        break;
      case "CLOSE_WIDGET":
        (_b = (_a = this.callbacks).onClose) == null ? void 0 : _b.call(_a);
        break;
    }
    (_d = (_c = this.callbacks).onMessage) == null ? void 0 : _d.call(_c, event.data);
  }
};

// src/sdk.ts
var SwipeluxWidget = class {
  constructor(settings, callbacks = {}) {
    this.settings = settings;
    this.callbacks = callbacks;
    this.container = null;
    this.iframe = null;
    this.iframeManager = null;
    if (!settings.apiKey) {
      throw new Error("API key is required");
    }
  }
  mount(container) {
    if (this.container) {
      throw new Error("Widget is already mounted");
    }
    this.container = container;
    this.iframe = document.createElement("iframe");
    Object.assign(this.iframe.style, IFRAME_STYLE);
    this.iframe.allow = IFRAME_PERMISSIONS;
    this.iframeManager = new WidgetIframeManager(
      this.iframe,
      this.settings,
      this.callbacks
    );
    this.container.appendChild(this.iframe);
    this.iframeManager.initialize();
  }
  unmount() {
    if (!this.container || !this.iframe || !this.iframeManager) {
      return;
    }
    this.iframeManager.destroy();
    this.container.removeChild(this.iframe);
    this.container = null;
    this.iframe = null;
    this.iframeManager = null;
  }
  isMounted() {
    return !!this.container && !!this.iframe && !!this.iframeManager;
  }
};

// src/web-component.ts
var SwipeluxWidgetElement = class extends HTMLElement {
  constructor() {
    super();
    this.settings = {};
    this.iframe = document.createElement("iframe");
    this.iframe.title = "Swipelux On-Ramp Widget";
    Object.assign(this.iframe.style, IFRAME_STYLE);
    this.iframe.allow = IFRAME_PERMISSIONS;
  }
  static get observedAttributes() {
    return [
      "widget-url",
      "api-key",
      "order-token",
      "payment-channel",
      "available-pay-currency",
      "available-receive-currency",
      "smart-contract-data",
      "default-values",
      "colors",
      "external-id",
      "signature",
      "force-new-transaction",
      "close-on-success"
    ];
  }
  connectedCallback() {
    this.appendChild(this.iframe);
    this.initializeWidget();
  }
  disconnectedCallback() {
    var _a;
    (_a = this.iframeManager) == null ? void 0 : _a.destroy();
  }
  // biome-ignore lint/suspicious/noExplicitAny: we have to use `any` here, sorry.
  parseComplexAttribute(name, value) {
    try {
      switch (name) {
        case "available-receive-currency": {
          try {
            return JSON.parse(value);
          } catch {
            return value;
          }
        }
        case "smart-contract-data":
          return JSON.parse(value);
        case "default-values":
          return JSON.parse(value);
        case "colors": {
          const colors = JSON.parse(value);
          for (const color of Object.values(colors)) {
            if (!color.match(/^(#|rgb\(|rgba\()/)) {
              throw new Error("Invalid color format");
            }
          }
          return colors;
        }
        case "signature":
          return JSON.parse(value);
        case "force-new-transaction":
        case "close-on-success":
          return value === "true";
        default:
          return value;
      }
    } catch (error) {
      console.error(`[Swipelux] Error parsing attribute ${name}:`, error);
      throw error;
    }
  }
  attributeChangedCallback(name, oldValue, newValue) {
    if (oldValue === newValue) {
      return;
    }
    const propName = name.replace(
      /-([a-z])/g,
      (_, letter) => letter.toUpperCase()
    );
    this.settings[propName] = this.parseComplexAttribute(name, newValue);
    this.initializeWidget();
  }
  initializeWidget() {
    var _a;
    if (!this.isConnected || !this.settings.apiKey) {
      return;
    }
    (_a = this.iframeManager) == null ? void 0 : _a.destroy();
    const callbacks = {
      onMessage: (event) => {
        this.dispatchEvent(new CustomEvent("message", { detail: event }));
      },
      onClose: () => {
        this.dispatchEvent(new CustomEvent("close"));
      }
    };
    this.iframeManager = new WidgetIframeManager(
      this.iframe,
      {
        apiKey: this.settings.apiKey,
        widgetUrl: this.settings.widgetUrl || "https://app.swipelux.com",
        ...this.settings
      },
      callbacks
    );
    this.iframeManager.initialize();
  }
  setColors(colors) {
    this.setAttribute("colors", JSON.stringify(colors));
  }
  setDefaultValues(values) {
    this.setAttribute("default-values", JSON.stringify(values));
  }
  setSignature(signature) {
    this.setAttribute("signature", JSON.stringify(signature));
  }
  setSmartContractData(data) {
    this.setAttribute("smart-contract-data", JSON.stringify(data));
  }
  setExternalId(id) {
    if (typeof id === "string") {
      this.setAttribute("external-id", id);
    } else {
      this.settings.externalId = id;
      this.initializeWidget();
    }
  }
  setReceiveCurrency(currency) {
    if (typeof currency === "string") {
      this.setAttribute("available-receive-currency", currency);
    } else {
      this.setAttribute("available-receive-currency", JSON.stringify(currency));
    }
  }
};

// src/index.browser.ts
window.SwipeluxWidget = SwipeluxWidget;
window.SwipeluxWidgetElement = SwipeluxWidgetElement;
customElements.define("swipelux-widget", SwipeluxWidgetElement);
//# sourceMappingURL=index.browser.js.map